Response parsing and element extraction.
Extracts items from HTTP responses and maps them to Drasi graph elements using the template engine.
Enums
- Mapped
Change - A mapped change result representing the operation to emit for an item.
Functions
- extract_
items - Extract items array from a response body using the configured items path.
- map_
items_ to_ elements - Map a list of items to Drasi graph elements using the configured mappings.